@@ -1,8 +1,8 @@
 # Natural Language Toolkit: Categorized Sentences Corpus Reader
 #
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: Pierpaolo Pantone <24alsecondo@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -13,7 +13,7 @@ Sentence Polarity Dataset.
 - Subjectivity Dataset information -
 
 Authors: Bo Pang and Lillian Lee.
-Url: http://www.cs.cornell.edu/people/pabo/movie-review-data
+Url: https://www.cs.cornell.edu/people/pabo/movie-review-data
 
 Distributed with permission.
 
@@ -26,7 +26,7 @@ Related papers:
 - Sentence Polarity Dataset information -
 
 Authors: Bo Pang and Lillian Lee.
-Url: http://www.cs.cornell.edu/people/pabo/movie-review-data
+Url: https://www.cs.cornell.edu/people/pabo/movie-review-data
 
 Related papers:
 
@@ -34,11 +34,11 @@ Related papers:
     sentiment categorization with respect to rating scales". Proceedings of the
     ACL, 2005.
 """
-from six import string_types
 
 from nltk.corpus.reader.api import *
 from nltk.tokenize import *
 
+
 class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
     """
     A reader for corpora in which each row represents a single instance, mainly
@@ -51,7 +51,7 @@ class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
     Examples using the Subjectivity Dataset:
 
     >>> from nltk.corpus import subjectivity
-    >>> subjectivity.sents()[23]
+    >>> subjectivity.sents()[23] # doctest: +NORMALIZE_WHITESPACE
     ['television', 'made', 'him', 'famous', ',', 'but', 'his', 'biggest', 'hits',
     'happened', 'off', 'screen', '.']
     >>> subjectivity.categories()
@@ -62,7 +62,7 @@ class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
     Examples using the Sentence Polarity Dataset:
 
     >>> from nltk.corpus import sentence_polarity
-    >>> sentence_polarity.sents()
+    >>> sentence_polarity.sents() # doctest: +NORMALIZE_WHITESPACE
     [['simplistic', ',', 'silly', 'and', 'tedious', '.'], ["it's", 'so', 'laddish',
     'and', 'juvenile', ',', 'only', 'teenage', 'boys', 'could', 'possibly', 'find',
     'it', 'funny', '.'], ...]
@@ -72,8 +72,15 @@ class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
 
     CorpusView = StreamBackedCorpusView
 
-    def __init__(self, root, fileids, word_tokenizer=WhitespaceTokenizer(),
-                 sent_tokenizer=None, encoding='utf8', **kwargs):
+    def __init__(
+        self,
+        root,
+        fileids,
+        word_tokenizer=WhitespaceTokenizer(),
+        sent_tokenizer=None,
+        encoding="utf8",
+        **kwargs
+    ):
         """
         :param root: The root directory for the corpus.
         :param fileids: a list or regexp specifying the fileids in the corpus.
@@ -89,36 +96,6 @@ class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
         self._word_tokenizer = word_tokenizer
         self._sent_tokenizer = sent_tokenizer
 
-    def _resolve(self, fileids, categories):
-        if fileids is not None and categories is not None:
-            raise ValueError('Specify fileids or categories, not both')
-        if categories is not None:
-            return self.fileids(categories)
-        else:
-            return fileids
-
-    def raw(self, fileids=None, categories=None):
-        """
-        :param fileids: a list or regexp specifying the fileids that have to be
-            returned as a raw string.
-        :param categories: a list specifying the categories whose files have to
-            be returned as a raw string.
-        :return: the given file(s) as a single string.
-        :rtype: str
-        """
-        fileids = self._resolve(fileids, categories)
-        if fileids is None:
-            fileids = self._fileids
-        elif isinstance(fileids, string_types):
-            fileids = [fileids]
-        return concat([self.open(f).read() for f in fileids])
-
-    def readme(self):
-        """
-        Return the contents of the corpus Readme.txt file.
-        """
-        return self.open("README").read()
-
     def sents(self, fileids=None, categories=None):
         """
         Return all sentences in the corpus or in the specified file(s).
@@ -134,10 +111,14 @@ class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
         fileids = self._resolve(fileids, categories)
         if fileids is None:
             fileids = self._fileids
-        elif isinstance(fileids, string_types):
+        elif isinstance(fileids, str):
             fileids = [fileids]
-        return concat([self.CorpusView(path, self._read_sent_block, encoding=enc)
-            for (path, enc, fileid) in self.abspaths(fileids, True, True)])
+        return concat(
+            [
+                self.CorpusView(path, self._read_sent_block, encoding=enc)
+                for (path, enc, fileid) in self.abspaths(fileids, True, True)
+            ]
+        )
 
     def words(self, fileids=None, categories=None):
         """
@@ -154,20 +135,28 @@ class CategorizedSentencesCorpusReader(CategorizedCorpusReader, CorpusReader):
         fileids = self._resolve(fileids, categories)
         if fileids is None:
             fileids = self._fileids
-        elif isinstance(fileids, string_types):
+        elif isinstance(fileids, str):
             fileids = [fileids]
-        return concat([self.CorpusView(path, self._read_word_block, encoding=enc)
-            for (path, enc, fileid) in self.abspaths(fileids, True, True)])
+        return concat(
+            [
+                self.CorpusView(path, self._read_word_block, encoding=enc)
+                for (path, enc, fileid) in self.abspaths(fileids, True, True)
+            ]
+        )
 
     def _read_sent_block(self, stream):
         sents = []
-        for i in range(20): # Read 20 lines at a time.
+        for i in range(20):  # Read 20 lines at a time.
             line = stream.readline()
             if not line:
                 continue
             if self._sent_tokenizer:
-                sents.extend([self._word_tokenizer.tokenize(sent)
-                              for sent in self._sent_tokenizer.tokenize(line)])
+                sents.extend(
+                    [
+                        self._word_tokenizer.tokenize(sent)
+                        for sent in self._sent_tokenizer.tokenize(line)
+                    ]
+                )
             else:
                 sents.append(self._word_tokenizer.tokenize(line))
         return sents
