@@ -1,20 +1,17 @@
 # Natural Language Toolkit: Dependency Corpus Reader
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: Kepa Sarasola <kepa.sarasola@ehu.es>
 #         Iker Manterola <returntothehangar@hotmail.com>
 #
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
-import codecs
-
+from nltk.corpus.reader.api import *
+from nltk.corpus.reader.util import *
 from nltk.parse import DependencyGraph
 from nltk.tokenize import *
 
-from nltk.corpus.reader.util import *
-from nltk.corpus.reader.api import *
-
 
 class DependencyCorpusReader(SyntaxCorpusReader):
     def __init__(
@@ -26,26 +23,10 @@ class DependencyCorpusReader(SyntaxCorpusReader):
         sent_tokenizer=RegexpTokenizer("\n", gaps=True),
         para_block_reader=read_blankline_block,
     ):
-        # FIXME: Why is it inheritting from SyntaxCorpusReader but initializing
-        #       from CorpusReader?
-        CorpusReader.__init__(self, root, fileids, encoding)
+        SyntaxCorpusReader.__init__(self, root, fileids, encoding)
 
     #########################################################
 
-    def raw(self, fileids=None):
-        """
-        :return: the given file(s) as a single string.
-        :rtype: str
-        """
-        result = []
-        for fileid, encoding in self.abspaths(fileids, include_encoding=True):
-            if isinstance(fileid, PathPointer):
-                result.append(fileid.open(encoding=encoding).read())
-            else:
-                with codecs.open(fileid, "r", encoding) as fp:
-                    result.append(fp.read())
-        return concat(result)
-
     def words(self, fileids=None):
         return concat(
             [
