@@ -1,8 +1,8 @@
 # Natural Language Toolkit: PanLex Corpus Reader
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: David Kamholz <kamholz@panlex.org>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -16,6 +16,7 @@ import sqlite3
 
 from nltk.corpus.reader.api import CorpusReader
 
+
 class PanLexLiteCorpusReader(CorpusReader):
     MEANING_Q = """
         SELECT dnx2.mn, dnx2.uq, dnx2.ap, dnx2.ui, ex2.tt, ex2.lv
@@ -42,12 +43,12 @@ class PanLexLiteCorpusReader(CorpusReader):
     """
 
     def __init__(self, root):
-        self._c = sqlite3.connect(os.path.join(root, 'db.sqlite')).cursor()
+        self._c = sqlite3.connect(os.path.join(root, "db.sqlite")).cursor()
 
         self._uid_lv = {}
         self._lv_uid = {}
 
-        for row in self._c.execute('SELECT uid, lv FROM lv'):
+        for row in self._c.execute("SELECT uid, lv FROM lv"):
             self._uid_lv[row[0]] = row[1]
             self._lv_uid[row[1]] = row[0]
 
@@ -63,10 +64,12 @@ class PanLexLiteCorpusReader(CorpusReader):
         :rtype: list(tuple)
         """
 
-        if lc == None:
-            return self._c.execute('SELECT uid, tt FROM lv ORDER BY uid').fetchall()
+        if lc is None:
+            return self._c.execute("SELECT uid, tt FROM lv ORDER BY uid").fetchall()
         else:
-            return self._c.execute('SELECT uid, tt FROM lv WHERE lc = ? ORDER BY uid', (lc,)).fetchall()
+            return self._c.execute(
+                "SELECT uid, tt FROM lv WHERE lc = ? ORDER BY uid", (lc,)
+            ).fetchall()
 
     def meanings(self, expr_uid, expr_tt):
         """
@@ -88,26 +91,31 @@ class PanLexLiteCorpusReader(CorpusReader):
             uid = self._lv_uid[i[5]]
 
             if not mn in mn_info:
-                mn_info[mn] = { 'uq': i[1], 'ap': i[2], 'ui': i[3], 'ex': { expr_uid: [expr_tt] } }
+                mn_info[mn] = {
+                    "uq": i[1],
+                    "ap": i[2],
+                    "ui": i[3],
+                    "ex": {expr_uid: [expr_tt]},
+                }
 
-            if not uid in mn_info[mn]['ex']:
-                mn_info[mn]['ex'][uid] = []
+            if not uid in mn_info[mn]["ex"]:
+                mn_info[mn]["ex"][uid] = []
 
-            mn_info[mn]['ex'][uid].append(i[4])
+            mn_info[mn]["ex"][uid].append(i[4])
 
-        return [ Meaning(mn, mn_info[mn]) for mn in mn_info ]
+        return [Meaning(mn, mn_info[mn]) for mn in mn_info]
 
     def translations(self, from_uid, from_tt, to_uid):
         """
         Return a list of translations for an expression into a single language
-            variety.
+        variety.
 
         :param from_uid: the source expression's language variety, as a
             seven-character uniform identifier.
         :param from_tt: the source expression's text.
         :param to_uid: the target language variety, as a seven-character
             uniform identifier.
-        :return a list of translation tuples. The first element is the expression 
+        :return: a list of translation tuples. The first element is the expression
             text and the second element is the translation quality.
         :rtype: list(tuple)
         """
@@ -117,6 +125,7 @@ class PanLexLiteCorpusReader(CorpusReader):
 
         return self._c.execute(self.TRANSLATION_Q, (from_lv, from_tt, to_lv)).fetchall()
 
+
 class Meaning(dict):
     """
     Represents a single PanLex meaning. A meaning is a translation set derived
@@ -124,36 +133,36 @@ class Meaning(dict):
     """
 
     def __init__(self, mn, attr):
-        super(Meaning, self).__init__(**attr)
-        self['mn'] = mn
+        super().__init__(**attr)
+        self["mn"] = mn
 
     def id(self):
         """
         :return: the meaning's id.
         :rtype: int
         """
-        return self['mn']
+        return self["mn"]
 
     def quality(self):
         """
         :return: the meaning's source's quality (0=worst, 9=best).
         :rtype: int
         """
-        return self['uq']
+        return self["uq"]
 
     def source(self):
         """
         :return: the meaning's source id.
         :rtype: int
         """
-        return self['ap']
+        return self["ap"]
 
     def source_group(self):
         """
         :return: the meaning's source group id.
         :rtype: int
         """
-        return self['ui']
+        return self["ui"]
 
     def expressions(self):
         """
@@ -162,4 +171,4 @@ class Meaning(dict):
             texts.
         :rtype: dict
         """
-        return self['ex']
+        return self["ex"]
