@@ -1497,7 +1497,11 @@ class DownloaderGUI:
         for (i, (key, label, callback)) in enumerate(info):
             Label(infoframe, text=label).grid(column=0, row=i, sticky="e")
             entry = Entry(
-                infoframe, font="courier", relief="groove", disabledforeground="black"
+                infoframe,
+                font="courier",
+                relief="groove",
+                disabledforeground="#007aff",
+                foreground="#007aff",
             )
             self._info[key] = (entry, callback)
             entry.bind("<Return>", self._info_save)
@@ -1647,12 +1651,12 @@ class DownloaderGUI:
         if self._table.column_names[col].endswith("Size"):
             if isinstance(val, str):
                 return "  %s" % val
-            elif val < 1024 ** 2:
-                return "  %.1f KB" % (val / 1024.0 ** 1)
-            elif val < 1024 ** 3:
-                return "  %.1f MB" % (val / 1024.0 ** 2)
+            elif val < 1024**2:
+                return "  %.1f KB" % (val / 1024.0**1)
+            elif val < 1024**3:
+                return "  %.1f MB" % (val / 1024.0**2)
             else:
-                return "  %.1f GB" % (val / 1024.0 ** 3)
+                return "  %.1f GB" % (val / 1024.0**3)
 
         if col in (0, ""):
             return str(val)
