@@ -80,18 +80,18 @@ class CanvasWidget(metaclass=ABCMeta):
     arguments of the form ``attribute=value``:
 
         >>> from nltk.draw.util import TextWidget
-        >>> cn = TextWidget(c, 'test', color='red')
+        >>> cn = TextWidget(Canvas(), 'test', color='red')  # doctest: +SKIP
 
     Attribute values can also be changed after a canvas widget has
     been constructed, using the ``__setitem__`` operator:
 
-        >>> cn['font'] = 'times'
+        >>> cn['font'] = 'times'  # doctest: +SKIP
 
     The current value of an attribute value can be queried using the
     ``__getitem__`` operator:
 
-        >>> cn['color']
-        red
+        >>> cn['color']  # doctest: +SKIP
+        'red'
 
     For a list of the attributes supported by a type of canvas widget,
     see its class documentation.
@@ -2216,7 +2216,7 @@ class ColorizedList:
         """
         Set up any colortags that will be used by this colorized list.
         E.g.:
-            >>> textwidget.tag_config('terminal', foreground='black')
+            textwidget.tag_config('terminal', foreground='black')
         """
 
     @abstractmethod
