@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: JSON Encoder/Decoder Helpers
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: Steven Xu <xxu@student.unimelb.edu.au>
 #
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -19,22 +18,22 @@ import json
 
 json_tags = {}
 
-TAG_PREFIX = '!'
+TAG_PREFIX = "!"
 
 
 def register_tag(cls):
     """
     Decorates a class to register it's json tag.
     """
-    json_tags[TAG_PREFIX + getattr(cls, 'json_tag')] = cls
+    json_tags[TAG_PREFIX + getattr(cls, "json_tag")] = cls
     return cls
 
 
 class JSONTaggedEncoder(json.JSONEncoder):
     def default(self, obj):
-        obj_tag = getattr(obj, 'json_tag', None)
+        obj_tag = getattr(obj, "json_tag", None)
         if obj_tag is None:
-            return super(JSONTaggedEncoder, self).default(obj)
+            return super().default(obj)
         obj_tag = TAG_PREFIX + obj_tag
         obj = obj.encode_json_obj()
         return {obj_tag: obj}
@@ -42,25 +41,25 @@ class JSONTaggedEncoder(json.JSONEncoder):
 
 class JSONTaggedDecoder(json.JSONDecoder):
     def decode(self, s):
-        return self.decode_obj(super(JSONTaggedDecoder, self).decode(s))
+        return self.decode_obj(super().decode(s))
 
     @classmethod
     def decode_obj(cls, obj):
         # Decode nested objects first.
         if isinstance(obj, dict):
-            obj = dict((key, cls.decode_obj(val)) for (key, val) in obj.items())
+            obj = {key: cls.decode_obj(val) for (key, val) in obj.items()}
         elif isinstance(obj, list):
             obj = list(cls.decode_obj(val) for val in obj)
         # Check if we have a tagged object.
         if not isinstance(obj, dict) or len(obj) != 1:
             return obj
         obj_tag = next(iter(obj.keys()))
-        if not obj_tag.startswith('!'):
+        if not obj_tag.startswith("!"):
             return obj
         if obj_tag not in json_tags:
-            raise ValueError('Unknown tag', obj_tag)
+            raise ValueError("Unknown tag", obj_tag)
         obj_cls = json_tags[obj_tag]
         return obj_cls.decode_json_obj(obj[obj_tag])
 
 
-__all__ = ['register_tag', 'json_tags', 'JSONTaggedEncoder', 'JSONTaggedDecoder']
+__all__ = ["register_tag", "json_tags", "JSONTaggedEncoder", "JSONTaggedDecoder"]
