@@ -1,8 +1,8 @@
 # Natural Language Toolkit: Agreement Metrics
 #
-# Copyright (C) 2001-2015 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: Lauri Hallila <laurihallila@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 #
 
@@ -24,15 +24,15 @@ from math import sqrt
 
 
 def get_words_from_dictionary(lemmas):
-    '''
+    """
     Get original set of words used for analysis.
 
     :param lemmas: A dictionary where keys are lemmas and values are sets
-    or lists of words corresponding to that lemma.
-    :type lemmas: dict
+        or lists of words corresponding to that lemma.
+    :type lemmas: dict(str): list(str)
     :return: Set of words that exist as values in the dictionary
-    :rtype: set
-    '''
+    :rtype: set(str)
+    """
     words = set()
     for lemma in lemmas:
         words.update(set(lemmas[lemma]))
@@ -40,37 +40,37 @@ def get_words_from_dictionary(lemmas):
 
 
 def _truncate(words, cutlength):
-    '''Group words by stems defined by truncating them at given length.
+    """Group words by stems defined by truncating them at given length.
 
     :param words: Set of words used for analysis
     :param cutlength: Words are stemmed by cutting at this length.
-    :type words: set or list
+    :type words: set(str) or list(str)
     :type cutlength: int
     :return: Dictionary where keys are stems and values are sets of words
     corresponding to that stem.
-    :rtype: dict
-    '''
+    :rtype: dict(str): set(str)
+    """
     stems = {}
     for word in words:
         stem = word[:cutlength]
         try:
             stems[stem].update([word])
         except KeyError:
-            stems[stem] = set([word])
+            stems[stem] = {word}
     return stems
 
 
-# Reference: http://en.wikipedia.org/wiki/Line-line_intersection
+# Reference: https://en.wikipedia.org/wiki/Line-line_intersection
 def _count_intersection(l1, l2):
-    '''Count intersection between two line segments defined by coordinate pairs.
+    """Count intersection between two line segments defined by coordinate pairs.
 
     :param l1: Tuple of two coordinate pairs defining the first line segment
     :param l2: Tuple of two coordinate pairs defining the second line segment
-    :type l1: tuple
-    :type l2: tuple
+    :type l1: tuple(float, float)
+    :type l2: tuple(float, float)
     :return: Coordinates of the intersection
-    :rtype: tuple
-    '''
+    :rtype: tuple(float, float)
+    """
     x1, y1 = l1[0]
     x2, y2 = l1[1]
     x3, y3 = l2[0]
@@ -78,7 +78,7 @@ def _count_intersection(l1, l2):
 
     denominator = (x1 - x2) * (y3 - y4) - (y1 - y2) * (x3 - x4)
 
-    if denominator == 0.0: # lines are parallel
+    if denominator == 0.0:  # lines are parallel
         if x1 == x2 == x3 == x4 == 0.0:
             # When lines are parallel, they must be on the y-axis.
             # We can ignore x-axis because we stop counting the
@@ -87,37 +87,41 @@ def _count_intersection(l1, l2):
             # OI (y-axis) diminishes when we go along the truncation line.
             return (0.0, y4)
 
-    x = ((x1 * y2 - y1 * x2) * (x3 - x4) - (x1 - x2) * (x3 * y4 - y3 * x4)) / denominator
-    y = ((x1 * y2 - y1 * x2) * (y3 - y4) - (y1 - y2) * (x3 * y4 - y3 * x4)) / denominator
+    x = (
+        (x1 * y2 - y1 * x2) * (x3 - x4) - (x1 - x2) * (x3 * y4 - y3 * x4)
+    ) / denominator
+    y = (
+        (x1 * y2 - y1 * x2) * (y3 - y4) - (y1 - y2) * (x3 * y4 - y3 * x4)
+    ) / denominator
     return (x, y)
 
 
 def _get_derivative(coordinates):
-    '''Get derivative of the line from (0,0) to given coordinates.
+    """Get derivative of the line from (0,0) to given coordinates.
 
     :param coordinates: A coordinate pair
-    :type coordinates: tuple
+    :type coordinates: tuple(float, float)
     :return: Derivative; inf if x is zero
     :rtype: float
-    '''
+    """
     try:
         return coordinates[1] / coordinates[0]
     except ZeroDivisionError:
-        return float('inf')
+        return float("inf")
 
 
 def _calculate_cut(lemmawords, stems):
-    '''Count understemmed and overstemmed pairs for (lemma, stem) pair with common words.
+    """Count understemmed and overstemmed pairs for (lemma, stem) pair with common words.
 
     :param lemmawords: Set or list of words corresponding to certain lemma.
     :param stems: A dictionary where keys are stems and values are sets
     or lists of words corresponding to that stem.
-    :type lemmawords: set or list
-    :type stems: dict
+    :type lemmawords: set(str) or list(str)
+    :type stems: dict(str): set(str)
     :return: Amount of understemmed and overstemmed pairs contributed by words
     existing in both lemmawords and stems.
-    :rtype: tuple
-    '''
+    :rtype: tuple(float, float)
+    """
     umt, wmt = 0.0, 0.0
     for stem in stems:
         cut = set(lemmawords) & set(stems[stem])
@@ -132,20 +136,20 @@ def _calculate_cut(lemmawords, stems):
 
 
 def _calculate(lemmas, stems):
-    '''Calculate actual and maximum possible amounts of understemmed and overstemmed word pairs.
+    """Calculate actual and maximum possible amounts of understemmed and overstemmed word pairs.
 
     :param lemmas: A dictionary where keys are lemmas and values are sets
     or lists of words corresponding to that lemma.
     :param stems: A dictionary where keys are stems and values are sets
     or lists of words corresponding to that stem.
-    :type lemmas: dict
-    :type stems: dict
+    :type lemmas: dict(str): list(str)
+    :type stems: dict(str): set(str)
     :return: Global unachieved merge total (gumt),
     global desired merge total (gdmt),
     global wrongly merged total (gwmt) and
     global desired non-merge total (gdnt).
-    :rtype: tuple
-    '''
+    :rtype: tuple(float, float, float, float)
+    """
 
     n = sum(len(lemmas[word]) for word in lemmas)
 
@@ -173,7 +177,7 @@ def _calculate(lemmas, stems):
 
 
 def _indexes(gumt, gdmt, gwmt, gdnt):
-    '''Count Understemming Index (UI), Overstemming Index (OI) and Stemming Weight (SW).
+    """Count Understemming Index (UI), Overstemming Index (OI) and Stemming Weight (SW).
 
     :param gumt, gdmt, gwmt, gdnt: Global unachieved merge total (gumt),
     global desired merge total (gdmt),
@@ -183,8 +187,8 @@ def _indexes(gumt, gdmt, gwmt, gdnt):
     :return: Understemming Index (UI),
     Overstemming Index (OI) and
     Stemming Weight (SW).
-    :rtype: tuple
-    '''
+    :rtype: tuple(float, float, float)
+    """
     # Calculate Understemming Index (UI),
     # Overstemming Index (OI) and Stemming Weight (SW)
     try:
@@ -202,24 +206,25 @@ def _indexes(gumt, gdmt, gwmt, gdnt):
     except ZeroDivisionError:
         if oi == 0.0:
             # OI and UI are 0, define SW as 'not a number'
-            sw = float('nan')
+            sw = float("nan")
         else:
             # UI is 0, define SW as infinity
-            sw = float('inf')
+            sw = float("inf")
     return (ui, oi, sw)
 
 
-class Paice(object):
-    '''Class for storing lemmas, stems and evaluation metrics.'''
+class Paice:
+    """Class for storing lemmas, stems and evaluation metrics."""
+
     def __init__(self, lemmas, stems):
-        '''
+        """
         :param lemmas: A dictionary where keys are lemmas and values are sets
-        or lists of words corresponding to that lemma.
+            or lists of words corresponding to that lemma.
         :param stems: A dictionary where keys are stems and values are sets
-        or lists of words corresponding to that stem.
-        :type lemmas: dict
-        :type stems: dict
-        '''
+            or lists of words corresponding to that stem.
+        :type lemmas: dict(str): list(str)
+        :type stems: dict(str): set(str)
+        """
         self.lemmas = lemmas
         self.stems = stems
         self.coords = []
@@ -229,28 +234,28 @@ class Paice(object):
         self.update()
 
     def __str__(self):
-        text = ['Global Unachieved Merge Total (GUMT): %s\n' % self.gumt]
-        text.append('Global Desired Merge Total (GDMT): %s\n' % self.gdmt)
-        text.append('Global Wrongly-Merged Total (GWMT): %s\n' % self.gwmt)
-        text.append('Global Desired Non-merge Total (GDNT): %s\n' % self.gdnt)
-        text.append('Understemming Index (GUMT / GDMT): %s\n' % self.ui)
-        text.append('Overstemming Index (GWMT / GDNT): %s\n' % self.oi)
-        text.append('Stemming Weight (OI / UI): %s\n' % self.sw)
-        text.append('Error-Rate Relative to Truncation (ERRT): %s\r\n' % self.errt)
-        coordinates = ' '.join(['(%s, %s)' % item for item in self.coords])
-        text.append('Truncation line: %s' % coordinates)
-        return ''.join(text)
+        text = ["Global Unachieved Merge Total (GUMT): %s\n" % self.gumt]
+        text.append("Global Desired Merge Total (GDMT): %s\n" % self.gdmt)
+        text.append("Global Wrongly-Merged Total (GWMT): %s\n" % self.gwmt)
+        text.append("Global Desired Non-merge Total (GDNT): %s\n" % self.gdnt)
+        text.append("Understemming Index (GUMT / GDMT): %s\n" % self.ui)
+        text.append("Overstemming Index (GWMT / GDNT): %s\n" % self.oi)
+        text.append("Stemming Weight (OI / UI): %s\n" % self.sw)
+        text.append("Error-Rate Relative to Truncation (ERRT): %s\r\n" % self.errt)
+        coordinates = " ".join(["(%s, %s)" % item for item in self.coords])
+        text.append("Truncation line: %s" % coordinates)
+        return "".join(text)
 
     def _get_truncation_indexes(self, words, cutlength):
-        '''Count (UI, OI) when stemming is done by truncating words at \'cutlength\'.
+        """Count (UI, OI) when stemming is done by truncating words at \'cutlength\'.
 
         :param words: Words used for the analysis
         :param cutlength: Words are stemmed by cutting them at this length
-        :type words: set or list
+        :type words: set(str) or list(str)
         :type cutlength: int
         :return: Understemming and overstemming indexes
-        :rtype: tuple
-        '''
+        :rtype: tuple(int, int)
+        """
 
         truncated = _truncate(words, cutlength)
         gumt, gdmt, gwmt, gdnt = _calculate(self.lemmas, truncated)
@@ -258,7 +263,7 @@ class Paice(object):
         return (ui, oi)
 
     def _get_truncation_coordinates(self, cutlength=0):
-        '''Count (UI, OI) pairs for truncation points until we find the segment where (ui, oi) crosses the truncation line.
+        """Count (UI, OI) pairs for truncation points until we find the segment where (ui, oi) crosses the truncation line.
 
         :param cutlength: Optional parameter to start counting from (ui, oi)
         coordinates gotten by stemming at this length. Useful for speeding up
@@ -266,8 +271,8 @@ class Paice(object):
         intersection.
         :type cutlength: int
         :return: List of coordinate pairs that define the truncation line
-        :rtype: list
-        '''
+        :rtype: list(tuple(float, float))
+        """
         words = get_words_from_dictionary(self.lemmas)
         maxlength = max(len(word) for word in words)
 
@@ -297,85 +302,88 @@ class Paice(object):
         return coords
 
     def _errt(self):
-        '''Count Error-Rate Relative to Truncation (ERRT).
+        """Count Error-Rate Relative to Truncation (ERRT).
 
         :return: ERRT, length of the line from origo to (UI, OI) divided by
         the length of the line from origo to the point defined by the same
         line when extended until the truncation line.
         :rtype: float
-        '''
+        """
         # Count (UI, OI) pairs for truncation points until we find the segment where (ui, oi) crosses the truncation line
         self.coords = self._get_truncation_coordinates()
         if (0.0, 0.0) in self.coords:
             # Truncation line goes through origo, so ERRT cannot be counted
             if (self.ui, self.oi) != (0.0, 0.0):
-                return float('inf')
+                return float("inf")
             else:
-                return float('nan')
+                return float("nan")
         if (self.ui, self.oi) == (0.0, 0.0):
             # (ui, oi) is origo; define errt as 0.0
             return 0.0
         # Count the intersection point
         # Note that (self.ui, self.oi) cannot be (0.0, 0.0) and self.coords has different coordinates
         # so we have actual line segments instead of a line segment and a point
-        intersection = _count_intersection(((0, 0), (self.ui, self.oi)),
-                                           self.coords[-2:]
-                                           )
+        intersection = _count_intersection(
+            ((0, 0), (self.ui, self.oi)), self.coords[-2:]
+        )
         # Count OP (length of the line from origo to (ui, oi))
-        op = sqrt(self.ui ** 2 + self.oi ** 2)
+        op = sqrt(self.ui**2 + self.oi**2)
         # Count OT (length of the line from origo to truncation line that goes through (ui, oi))
         ot = sqrt(intersection[0] ** 2 + intersection[1] ** 2)
         # OP / OT tells how well the stemming algorithm works compared to just truncating words
         return op / ot
 
     def update(self):
-        '''Update statistics after lemmas and stems have been set.'''
+        """Update statistics after lemmas and stems have been set."""
         self.gumt, self.gdmt, self.gwmt, self.gdnt = _calculate(self.lemmas, self.stems)
         self.ui, self.oi, self.sw = _indexes(self.gumt, self.gdmt, self.gwmt, self.gdnt)
         self.errt = self._errt()
 
 
 def demo():
-    '''Demonstration of the module.'''
+    """Demonstration of the module."""
     # Some words with their real lemmas
-    lemmas = {'kneel': ['kneel', 'knelt'],
-              'range': ['range', 'ranged'],
-              'ring': ['ring', 'rang', 'rung']
-              }
+    lemmas = {
+        "kneel": ["kneel", "knelt"],
+        "range": ["range", "ranged"],
+        "ring": ["ring", "rang", "rung"],
+    }
     # Same words with stems from a stemming algorithm
-    stems = {'kneel': ['kneel'],
-             'knelt': ['knelt'],
-             'rang': ['rang', 'range', 'ranged'],
-             'ring': ['ring'],
-             'rung': ['rung']
-             }
-    print('Words grouped by their lemmas:')
+    stems = {
+        "kneel": ["kneel"],
+        "knelt": ["knelt"],
+        "rang": ["rang", "range", "ranged"],
+        "ring": ["ring"],
+        "rung": ["rung"],
+    }
+    print("Words grouped by their lemmas:")
     for lemma in sorted(lemmas):
-        print('%s => %s' % (lemma, ' '.join(lemmas[lemma])))
+        print("{} => {}".format(lemma, " ".join(lemmas[lemma])))
     print()
-    print('Same words grouped by a stemming algorithm:')
+    print("Same words grouped by a stemming algorithm:")
     for stem in sorted(stems):
-        print('%s => %s' % (stem, ' '.join(stems[stem])))
+        print("{} => {}".format(stem, " ".join(stems[stem])))
     print()
     p = Paice(lemmas, stems)
     print(p)
     print()
     # Let's "change" results from a stemming algorithm
-    stems = {'kneel': ['kneel'],
-             'knelt': ['knelt'],
-             'rang': ['rang'],
-             'range': ['range', 'ranged'],
-             'ring': ['ring'],
-             'rung': ['rung']
-             }
-    print('Counting stats after changing stemming results:')
+    stems = {
+        "kneel": ["kneel"],
+        "knelt": ["knelt"],
+        "rang": ["rang"],
+        "range": ["range", "ranged"],
+        "ring": ["ring"],
+        "rung": ["rung"],
+    }
+    print("Counting stats after changing stemming results:")
     for stem in sorted(stems):
-        print('%s => %s' % (stem, ' '.join(stems[stem])))
+        print("{} => {}".format(stem, " ".join(stems[stem])))
     print()
     p.stems = stems
     p.update()
     print(p)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
