@@ -61,9 +61,9 @@ class DependencyEvaluator:
     >>> de = DependencyEvaluator([parsed_sent],[gold_sent])
     >>> las, uas = de.eval()
     >>> las
-    0.6...
+    0.6
     >>> uas
-    0.8...
+    0.8
     >>> abs(uas - 0.8) < 0.00001
     True
     """
