@@ -33,6 +33,8 @@ class Tokens:
     EXISTS_LIST = ["some", "exists", "exist"]
     ALL = "all"
     ALL_LIST = ["all", "forall"]
+    IOTA = "iota"
+    IOTA_LIST = ["iota"]
 
     # Punctuation
     DOT = "."
@@ -58,7 +60,7 @@ class Tokens:
 
     # Collections of tokens
     BINOPS = AND_LIST + OR_LIST + IMP_LIST + IFF_LIST
-    QUANTS = EXISTS_LIST + ALL_LIST
+    QUANTS = EXISTS_LIST + ALL_LIST + IOTA_LIST
     PUNCT = [DOT, OPEN, CLOSE, COMMA]
 
     TOKENS = BINOPS + EQ_LIST + NEQ_LIST + QUANTS + LAMBDA_LIST + PUNCT + NOT_LIST
@@ -90,7 +92,7 @@ def binding_ops():
     Binding operators
     """
     names = ["existential", "universal", "lambda"]
-    for pair in zip(names, [Tokens.EXISTS, Tokens.ALL, Tokens.LAMBDA]):
+    for pair in zip(names, [Tokens.EXISTS, Tokens.ALL, Tokens.LAMBDA, Tokens.IOTA]):
         print("%-15s\t%s" % pair)
 
 
@@ -434,6 +436,8 @@ class LogicParser:
             return ExistsExpression
         elif tok in Tokens.ALL_LIST:
             return AllExpression
+        elif tok in Tokens.IOTA_LIST:
+            return IotaExpression
         else:
             self.assertToken(tok, Tokens.QUANTS)
 
@@ -991,7 +995,7 @@ class Expression(SubstituteBindingsI):
         return IffExpression(self, other)
 
     def __eq__(self, other):
-        raise NotImplementedError()
+        return NotImplemented
 
     def __ne__(self, other):
         return not self == other
@@ -1755,6 +1759,11 @@ class AllExpression(QuantifiedExpression):
         return Tokens.ALL
 
 
+class IotaExpression(QuantifiedExpression):
+    def getQuantifier(self):
+        return Tokens.IOTA
+
+
 class NegatedExpression(Expression):
     def __init__(self, term):
         assert isinstance(term, Expression), "%s is not an Expression" % term
