@@ -2,8 +2,8 @@
 #
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>
 #
-# Copyright (C) 2001-2020 NLTK Project
-# URL: <http://nltk.org/>
+# Copyright (C) 2001-2022 NLTK Project
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 from nltk.sem.logic import (
@@ -34,8 +34,8 @@ def skolemize(expression, univ_scope=None, used_variables=None):
     if isinstance(expression, AllExpression):
         term = skolemize(
             expression.term,
-            univ_scope | set([expression.variable]),
-            used_variables | set([expression.variable]),
+            univ_scope | {expression.variable},
+            used_variables | {expression.variable},
         )
         return term.replace(
             expression.variable,
@@ -69,7 +69,7 @@ def skolemize(expression, univ_scope=None, used_variables=None):
         negated = expression.term
         if isinstance(negated, AllExpression):
             term = skolemize(
-                -negated.term, univ_scope, used_variables | set([negated.variable])
+                -negated.term, univ_scope, used_variables | {negated.variable}
             )
             if univ_scope:
                 return term.replace(negated.variable, skolem_function(univ_scope))
@@ -106,8 +106,8 @@ def skolemize(expression, univ_scope=None, used_variables=None):
         elif isinstance(negated, ExistsExpression):
             term = skolemize(
                 -negated.term,
-                univ_scope | set([negated.variable]),
-                used_variables | set([negated.variable]),
+                univ_scope | {negated.variable},
+                used_variables | {negated.variable},
             )
             return term.replace(
                 negated.variable,
@@ -119,7 +119,7 @@ def skolemize(expression, univ_scope=None, used_variables=None):
             raise Exception("'%s' cannot be skolemized" % expression)
     elif isinstance(expression, ExistsExpression):
         term = skolemize(
-            expression.term, univ_scope, used_variables | set([expression.variable])
+            expression.term, univ_scope, used_variables | {expression.variable}
         )
         if univ_scope:
             return term.replace(expression.variable, skolem_function(univ_scope))
