@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Stack decoder
 #
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: Tah Wei Hoon <hoon.tw@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -13,8 +12,8 @@ Tests for stack decoder
 import unittest
 from collections import defaultdict
 from math import log
-from nltk.translate import PhraseTable
-from nltk.translate import StackDecoder
+
+from nltk.translate import PhraseTable, StackDecoder
 from nltk.translate.stack_decoder import _Hypothesis, _Stack
 
 
@@ -23,7 +22,7 @@ class TestStackDecoder(unittest.TestCase):
         # arrange
         phrase_table = TestStackDecoder.create_fake_phrase_table()
         stack_decoder = StackDecoder(phrase_table, None)
-        sentence = ('my', 'hovercraft', 'is', 'full', 'of', 'eels')
+        sentence = ("my", "hovercraft", "is", "full", "of", "eels")
 
         # act
         src_phrase_spans = stack_decoder.find_all_src_phrases(sentence)
@@ -68,7 +67,7 @@ class TestStackDecoder(unittest.TestCase):
         phrase_table = TestStackDecoder.create_fake_phrase_table()
         language_model = TestStackDecoder.create_fake_language_model()
         stack_decoder = StackDecoder(phrase_table, language_model)
-        sentence = ('my', 'hovercraft', 'is', 'full', 'of', 'eels')
+        sentence = ("my", "hovercraft", "is", "full", "of", "eels")
 
         # act
         future_scores = stack_decoder.compute_future_scores(sentence)
@@ -76,19 +75,25 @@ class TestStackDecoder(unittest.TestCase):
         # assert
         self.assertEqual(
             future_scores[1][2],
-            (phrase_table.translations_for(('hovercraft',))[0].log_prob +
-             language_model.probability(('hovercraft',))))
+            (
+                phrase_table.translations_for(("hovercraft",))[0].log_prob
+                + language_model.probability(("hovercraft",))
+            ),
+        )
         self.assertEqual(
             future_scores[0][2],
-            (phrase_table.translations_for(('my', 'hovercraft'))[0].log_prob +
-             language_model.probability(('my', 'hovercraft'))))
+            (
+                phrase_table.translations_for(("my", "hovercraft"))[0].log_prob
+                + language_model.probability(("my", "hovercraft"))
+            ),
+        )
 
     def test_compute_future_costs_for_phrases_not_in_phrase_table(self):
         # arrange
         phrase_table = TestStackDecoder.create_fake_phrase_table()
         language_model = TestStackDecoder.create_fake_language_model()
         stack_decoder = StackDecoder(phrase_table, language_model)
-        sentence = ('my', 'hovercraft', 'is', 'full', 'of', 'eels')
+        sentence = ("my", "hovercraft", "is", "full", "of", "eels")
 
         # act
         future_scores = stack_decoder.compute_future_scores(sentence)
@@ -96,7 +101,8 @@ class TestStackDecoder(unittest.TestCase):
         # assert
         self.assertEqual(
             future_scores[1][3],  # 'hovercraft is' is not in phrase table
-            future_scores[1][2] + future_scores[2][3])  # backoff
+            future_scores[1][2] + future_scores[2][3],
+        )  # backoff
 
     def test_future_score(self):
         # arrange: sentence with 8 words; words 2, 3, 4 already translated
@@ -108,8 +114,7 @@ class TestStackDecoder(unittest.TestCase):
         stack_decoder = StackDecoder(None, None)
 
         # act
-        future_score = stack_decoder.future_score(
-            hypothesis, future_score_table, 8)
+        future_score = stack_decoder.future_score(hypothesis, future_score_table, 8)
 
         # assert
         self.assertEqual(future_score, 0.4 + 0.5)
@@ -118,19 +123,8 @@ class TestStackDecoder(unittest.TestCase):
         # arrange
         hypothesis = _Hypothesis()
         # mock untranslated_spans method
-        hypothesis.untranslated_spans = lambda _: [
-            (0, 2),
-            (3, 6)
-        ]
-        all_phrases_from = [
-            [1, 4],
-            [2],
-            [],
-            [5],
-            [5, 6, 7],
-            [],
-            [7]
-        ]
+        hypothesis.untranslated_spans = lambda _: [(0, 2), (3, 6)]
+        all_phrases_from = [[1, 4], [2], [], [5], [5, 6, 7], [], [7]]
 
         # act
         phrase_spans = StackDecoder.valid_phrases(all_phrases_from, hypothesis)
@@ -141,32 +135,32 @@ class TestStackDecoder(unittest.TestCase):
     @staticmethod
     def create_fake_phrase_table():
         phrase_table = PhraseTable()
-        phrase_table.add(('hovercraft',), ('',), 0.8)
-        phrase_table.add(('my', 'hovercraft'), ('', ''), 0.7)
-        phrase_table.add(('my', 'cheese'), ('', ''), 0.7)
-        phrase_table.add(('is',), ('',), 0.8)
-        phrase_table.add(('is',), ('',), 0.5)
-        phrase_table.add(('full', 'of'), ('', ''), 0.01)
-        phrase_table.add(('full', 'of', 'eels'), ('', '', ''), 0.5)
-        phrase_table.add(('full', 'of', 'spam'), ('', ''), 0.5)
-        phrase_table.add(('eels',), ('',), 0.5)
-        phrase_table.add(('spam',), ('',), 0.5)
+        phrase_table.add(("hovercraft",), ("",), 0.8)
+        phrase_table.add(("my", "hovercraft"), ("", ""), 0.7)
+        phrase_table.add(("my", "cheese"), ("", ""), 0.7)
+        phrase_table.add(("is",), ("",), 0.8)
+        phrase_table.add(("is",), ("",), 0.5)
+        phrase_table.add(("full", "of"), ("", ""), 0.01)
+        phrase_table.add(("full", "of", "eels"), ("", "", ""), 0.5)
+        phrase_table.add(("full", "of", "spam"), ("", ""), 0.5)
+        phrase_table.add(("eels",), ("",), 0.5)
+        phrase_table.add(("spam",), ("",), 0.5)
         return phrase_table
 
     @staticmethod
     def create_fake_language_model():
         # nltk.model should be used here once it is implemented
         language_prob = defaultdict(lambda: -999.0)
-        language_prob[('my',)] = log(0.1)
-        language_prob[('hovercraft',)] = log(0.1)
-        language_prob[('is',)] = log(0.1)
-        language_prob[('full',)] = log(0.1)
-        language_prob[('of',)] = log(0.1)
-        language_prob[('eels',)] = log(0.1)
-        language_prob[('my', 'hovercraft',)] = log(0.3)
+        language_prob[("my",)] = log(0.1)
+        language_prob[("hovercraft",)] = log(0.1)
+        language_prob[("is",)] = log(0.1)
+        language_prob[("full",)] = log(0.1)
+        language_prob[("of",)] = log(0.1)
+        language_prob[("eels",)] = log(0.1)
+        language_prob[("my", "hovercraft")] = log(0.3)
         language_model = type(
-            '', (object,),
-            {'probability': lambda _, phrase: language_prob[phrase]})()
+            "", (object,), {"probability": lambda _, phrase: language_prob[phrase]}
+        )()
         return language_model
 
 
@@ -176,14 +170,14 @@ class TestHypothesis(unittest.TestCase):
         child = _Hypothesis(
             raw_score=0.5,
             src_phrase_span=(3, 7),
-            trg_phrase=('hello', 'world'),
-            previous=root
+            trg_phrase=("hello", "world"),
+            previous=root,
         )
         grandchild = _Hypothesis(
             raw_score=0.4,
             src_phrase_span=(1, 2),
-            trg_phrase=('and', 'goodbye'),
-            previous=child
+            trg_phrase=("and", "goodbye"),
+            previous=child,
         )
         self.hypothesis_chain = grandchild
 
@@ -192,7 +186,7 @@ class TestHypothesis(unittest.TestCase):
         translation = self.hypothesis_chain.translation_so_far()
 
         # assert
-        self.assertEqual(translation, ['hello', 'world', 'and', 'goodbye'])
+        self.assertEqual(translation, ["hello", "world", "and", "goodbye"])
 
     def test_translation_so_far_for_empty_hypothesis(self):
         # arrange
